.. _filters:

Filter Methods
==============

* `IndexList`_
* `SnapshotList`_

IndexList
---------

.. automethod:: curator.indexlist.IndexList.filter_allocated
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_by_age
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_by_regex
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_by_space
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_closed
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_forceMerged
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_kibana
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_opened
   :noindex:

.. automethod:: curator.indexlist.IndexList.filter_none
  :noindex:

.. automethod:: curator.indexlist.IndexList.filter_by_alias
  :noindex:

.. automethod:: curator.indexlist.IndexList.filter_by_count
   :noindex:

SnapshotList
------------

.. automethod:: curator.snapshotlist.SnapshotList.filter_by_age
   :noindex:

.. automethod:: curator.snapshotlist.SnapshotList.filter_by_regex
   :noindex:

.. automethod:: curator.snapshotlist.SnapshotList.filter_by_state
  :noindex:

.. automethod:: curator.snapshotlist.SnapshotList.filter_none
  :noindex:

.. automethod:: curator.snapshotlist.SnapshotList.filter_by_count
  :noindex:
